@@ -9,7 +9,7 @@ sub get {
         uri        => { isa => 'Str', xor => [qw(schema host path_query)] },
 
         schema     => { isa => 'Str', default => 'http' },
-        host       => { isa => 'Str', default => '127.0.0.1' },
+        host       => { isa => 'Str' },
         path_query => { isa => 'Str', default => '/' },
 
         method     => { isa => 'Str', default => 'GET' },
